@@ -23,26 +23,40 @@ describe 'gnocchi::storage::ceph' do
         is_expected.to contain_gnocchi_config('storage/ceph_conffile').with_value('/etc/ceph/ceph.conf')
       end
     end
-  end
 
-  context 'on Debian platforms' do
-    let :facts do
-      {
-        :osfamily       => 'Debian'
-      }
+    context 'with ceph_secret parameter' do
+      before do
+        params.merge!({
+          :ceph_secret => 'secrete'})
+      end
+      it { is_expected.to contain_gnocchi_config('storage/ceph_secret').with_value('secrete') }
     end
 
-    it_configures 'gnocchi storage ceph'
-  end
-
-  context 'on RedHat platforms' do
-    let :facts do
-      {
-        :osfamily       => 'RedHat'
-      }
+    context 'without required parameters' do
+      before { params.delete(:ceph_keyring) }
+      it { expect { is_expected.to raise_error(Puppet::Error) } }
     end
 
-    it_configures 'gnocchi storage ceph'
+    context 'with both required parameters set to false' do
+      before do
+        params.merge!({
+          :ceph_secret  => false,
+          :ceph_keyring => false,
+        })
+      end
+      it { expect { is_expected.to raise_error(Puppet::Error) } }
+    end
   end
 
+  on_supported_os({
+    :supported_os   => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
+
+      it_behaves_like 'gnocchi storage ceph'
+    end
+  end
 end
